@@ -13,6 +13,8 @@ mod copy_rand;
 pub use copy_rand::{CopyRand, CopyRandBuilder};
 mod filter;
 pub use filter::Filter;
+mod fir;
+pub use fir::Fir;
 
 #[cfg(not(target_arch = "wasm32"))]
 mod fft;
@@ -33,6 +35,10 @@ mod finite_source;
 pub use finite_source::FiniteSource;
 mod head;
 pub use head::{Head, HeadBuilder};
+
+#[cfg(feature = "lttng")]
+pub mod lttng;
+
 mod message_burst;
 pub use message_burst::{MessageBurst, MessageBurstBuilder};
 mod message_copy;
