@@ -1,10 +1,10 @@
-use anyhow::Result;
 use async_io::Timer;
 use std::cmp;
 use std::ptr;
 use std::time::Duration;
 use std::time::Instant;
 
+use crate::anyhow::Result;
 use crate::runtime::AsyncKernel;
 use crate::runtime::Block;
 use crate::runtime::BlockMeta;
