@@ -1,5 +1,3 @@
-use anyhow::Context as _;
-use anyhow::Result;
 use async_io::Async;
 use async_tungstenite::tungstenite::Message;
 use async_tungstenite::WebSocketStream;
@@ -14,6 +12,8 @@ use std::pin::Pin;
 use std::sync::Arc;
 use std::task::{Context, Poll};
 
+use crate::anyhow::Context as _;
+use crate::anyhow::Result;
 use crate::runtime::AsyncKernel;
 use crate::runtime::Block;
 use crate::runtime::BlockMeta;
@@ -30,7 +30,7 @@ pub enum WebsocketSinkMode {
     FixedDropping(usize),
 }
 
-pub struct WebsocketSink<T: Send + Sync + 'static> {
+pub struct WebsocketSink<T> {
     port: u32,
     listener: Option<Arc<Async<TcpListener>>>,
     conn: Option<WsStream>,
@@ -164,7 +164,7 @@ impl<T: Send + Sync + 'static> AsyncKernel for WebsocketSink<T> {
     }
 }
 
-pub struct WebsocketSinkBuilder<T: Send + Sync + 'static> {
+pub struct WebsocketSinkBuilder<T> {
     port: u32,
     mode: WebsocketSinkMode,
     _p: PhantomData<T>,
