@@ -1,6 +1,6 @@
-#[cfg(not(target_arch = "wasm32"))]
+#[cfg(feature = "flow_scheduler")]
 mod flow;
-#[cfg(not(target_arch = "wasm32"))]
+#[cfg(feature = "flow_scheduler")]
 pub use crate::runtime::scheduler::flow::FlowScheduler;
 
 #[cfg(not(target_arch = "wasm32"))]
@@ -8,9 +8,9 @@ mod smol;
 #[cfg(not(target_arch = "wasm32"))]
 pub use crate::runtime::scheduler::smol::SmolScheduler;
 
-#[cfg(not(target_arch = "wasm32"))]
+#[cfg(feature = "tpb_scheduler")]
 mod tpb;
-#[cfg(not(target_arch = "wasm32"))]
+#[cfg(feature = "tpb_scheduler")]
 pub use crate::runtime::scheduler::tpb::TpbScheduler;
 
 #[allow(clippy::module_inception)]
