@@ -1,6 +1,6 @@
-use anyhow::Result;
 use std::iter::repeat_with;
 
+use futuresdr::anyhow::Result;
 use futuresdr::blocks::CopyBuilder;
 use futuresdr::blocks::HeadBuilder;
 use futuresdr::blocks::NullSourceBuilder;
