@@ -1,9 +1,9 @@
 #[cfg(feature = "vulkan")]
 mod inner {
-    use anyhow::Result;
     use std::iter::repeat_with;
     use std::sync::Arc;
 
+    use futuresdr::anyhow::Result;
     use futuresdr::blocks::VectorSink;
     use futuresdr::blocks::VectorSinkBuilder;
     use futuresdr::blocks::VectorSourceBuilder;
